tests.test_constants module — justbases 0.07 documentation

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »

# tests.test_constants module

Test for integer conversions.

class `tests.test_constants.` `RoundingMethodsTestCase`(methodName='runTest')

  Bases: `unittest.case.TestCase`

  Tests for RoundingMethods constants.

  `testStr`()

    Test __str__ and __repr__ method.

### Navigation

- index
- modules |
- next |
- previous |
- justbases 0.07 documentation »
- tests »
- tests package »